@@ -2,12 +2,13 @@
 # This example shows how to properly write out a pdb of the structure
 # results when using coarse grained rigid bodies.
 
+from __future__ import print_function
 import IMP.atom
 
 m = IMP.kernel.Model()
 full = IMP.atom.read_pdb(IMP.atom.get_example_path("example_protein.pdb"), m)
 chain = IMP.atom.get_by_type(full, IMP.atom.CHAIN_TYPE)[0]
-print chain
+print(chain)
 # for some reason the python wrapper won't make the implicit conversion to
 # Chain
 simplified = IMP.atom.create_simplified_along_backbone(
